==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/FirmwareFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class FirmwareFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent<A>{
  public FirmwareFluentImpl() {
  }
  public FirmwareFluentImpl(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.Firmware instance) {
    this.withBios(instance.getBios()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSBuilder bios;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildBios instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOS getBios() {
    return this.bios!=null?this.bios.build():null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOS buildBios() {
    return this.bios!=null?this.bios.build():null;
  }
  public A withBios(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOS bios) {
    _visitables.get("bios").remove(this.bios);
    if (bios!=null){ this.bios= new io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSBuilder(bios); _visitables.get("bios").add(this.bios);} return (A) this;
  }
  public java.lang.Boolean hasBios() {
    return this.bios != null;
  }
  public A withNewBios(java.lang.String date,java.lang.String vendor,java.lang.String version) {
    return (A)withBios(new BIOS(date, vendor, version));
  }
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent.BiosNested<A> withNewBios() {
    return new io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluentImpl.BiosNestedImpl();
  }
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent.BiosNested<A> withNewBiosLike(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOS item) {
    return new io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluentImpl.BiosNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent.BiosNested<A> editBios() {
    return withNewBiosLike(getBios());
  }
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent.BiosNested<A> editOrNewBios() {
    return withNewBiosLike(getBios() != null ? getBios(): new io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSBuilder().build());
  }
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent.BiosNested<A> editOrNewBiosLike(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOS item) {
    return withNewBiosLike(getBios() != null ? getBios(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    FirmwareFluentImpl that = (FirmwareFluentImpl) o;
    if (bios != null ? !bios.equals(that.bios) :that.bios != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(bios,  additionalProperties,  super.hashCode());
  }
  public class BiosNestedImpl<N> extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSFluentImpl<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent.BiosNested<N>> implements io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent.BiosNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    BiosNestedImpl(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOS item) {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSBuilder(this, item);
    }
    BiosNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSBuilder(this);
    }
    io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSBuilder builder;
    public N and() {
      return (N) FirmwareFluentImpl.this.withBios(builder.build());
    }
    public N endBios() {
      return and();
    }
    
  }
  
}

==> openshift-model-miscellaneous-5.12.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/FirmwareFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class FirmwareFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent<A>{
  public FirmwareFluentImpl() {
  }
  public FirmwareFluentImpl(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.Firmware instance) {
    this.withBios(instance.getBios()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSBuilder bios;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildBios instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOS getBios() {
    return this.bios!=null?this.bios.build():null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOS buildBios() {
    return this.bios!=null?this.bios.build():null;
  }
  public A withBios(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOS bios) {
    _visitables.get("bios").remove(this.bios);
    if (bios!=null){ this.bios= new io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSBuilder(bios); _visitables.get("bios").add(this.bios);} return (A) this;
  }
  public java.lang.Boolean hasBios() {
    return this.bios != null;
  }
  public A withNewBios(java.lang.String date,java.lang.String vendor,java.lang.String version) {
    return (A)withBios(new BIOS(date, vendor, version));
  }
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent.BiosNested<A> withNewBios() {
    return new io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluentImpl.BiosNestedImpl();
  }
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent.BiosNested<A> withNewBiosLike(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOS item) {
    return new io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluentImpl.BiosNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent.BiosNested<A> editBios() {
    return withNewBiosLike(getBios());
  }
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent.BiosNested<A> editOrNewBios() {
    return withNewBiosLike(getBios() != null ? getBios(): new io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSBuilder().build());
  }
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent.BiosNested<A> editOrNewBiosLike(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOS item) {
    return withNewBiosLike(getBios() != null ? getBios(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    FirmwareFluentImpl that = (FirmwareFluentImpl) o;
    if (bios != null ? !bios.equals(that.bios) :that.bios != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(bios,  additionalProperties,  super.hashCode());
  }
  public class BiosNestedImpl<N> extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSFluentImpl<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent.BiosNested<N>> implements io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareFluent.BiosNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    BiosNestedImpl(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOS item) {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSBuilder(this, item);
    }
    BiosNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSBuilder(this);
    }
    io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BIOSBuilder builder;
    public N and() {
      return (N) FirmwareFluentImpl.this.withBios(builder.build());
    }
    public N endBios() {
      return and();
    }
    
  }
  
}
